pub struct CleanupPlan {
pub action: CleanupAction,
pub affected_classes: Vec<DataClass>,
pub estimated_recovered_bytes: u64,
pub requires_rebuild: bool,
pub requires_confirmation: bool,
}Expand description
A cleanup plan: produced first, executed second (RFC-001 14).
Fields
action: CleanupActionaffected_classes: Vec<DataClass>estimated_recovered_bytes: u64requires_rebuild: boolrequires_confirmation: boolImplementations
Sourceimpl CleanupPlan
impl CleanupPlan
Sourcepub fn for_action(action: CleanupAction, estimated_recovered_bytes: u64) -> Self
pub fn for_action(action: CleanupAction, estimated_recovered_bytes: u64) -> Self
Build the plan for an action with an estimated byte impact.
Sourcepub fn assert_safe_for_ordinary_cleanup(&self) -> Result<(), OrbokError>
pub fn assert_safe_for_ordinary_cleanup(&self) -> Result<(), OrbokError>
Safe cleanup must never include the persistent catalog. Executors call this before running anything that has not been explicitly confirmed as a destructive reset.